package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class NestHost extends Attribute
{
    private int hostClassIndex;
    
    NestHost(final int nameIndex, final int length, final DataInput input, final ConstantPool constantPool) throws IOException {
        this(nameIndex, length, 0, constantPool);
        this.hostClassIndex = input.readUnsignedShort();
    }
    
    public NestHost(final int nameIndex, final int length, final int hostClassIndex, final ConstantPool constantPool) {
        super((byte)26, nameIndex, length, constantPool);
        this.hostClassIndex = hostClassIndex;
    }
    
    public NestHost(final NestHost c) {
        this(c.getNameIndex(), c.getLength(), c.getHostClassIndex(), c.getConstantPool());
    }
    
    @Override
    public void accept(final Visitor v) {
        v.visitNestHost(this);
    }
    
    @Override
    public Attribute copy(final ConstantPool constantPool) {
        final NestHost c = (NestHost)this.clone();
        c.setConstantPool(constantPool);
        return c;
    }
    
    @Override
    public void dump(final DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.hostClassIndex);
    }
    
    public int getHostClassIndex() {
        return this.hostClassIndex;
    }
    
    public void setHostClassIndex(final int hostClassIndex) {
        this.hostClassIndex = hostClassIndex;
    }
    
    @Override
    public String toString() {
        final StringBuilder buf = new StringBuilder();
        buf.append("NestHost: ");
        final String className = super.getConstantPool().getConstantString(this.hostClassIndex, (byte)7);
        buf.append(Utility.compactClassName(className, false));
        return buf.toString();
    }
}
